# aiokilogram

Convenience tools and wrappers for `aiogram`,
the asynchronous Telegram Bot API framework.


## Installation

```bash
pip install aiokilogram
```


## Basic Examples

TODO


## Links

Homepage on GitHub: https://github.com/altvod/aiokilogram

Project's page on PyPi: https://pypi.org/project/aiokilogram/

`aiogram`'s homepage on GitHub: https://github.com/aiogram/aiogram

Telegram Bot API: https://core.telegram.org/bots/api
